#ifndef NT2_INCLUDE_FUNCTIONS_ABSS_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ABSS_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/abss.hpp>

#endif
